//#define XERR
#include "loop.ih"

// -----------------------------------
// iteration  women years  total costs
// -----------------------------------
//         0,         795,       13478
// -----------------------------------


CSVTable Loop::headerSensitivity() const
{
xerr("0");

    CSVTable tab{ outStream(d_options.sensitivityFile(), 0), "  " };

xerr("1");
    if (not tab.stream())
        return tab;

xerr("2");
    labels(tab.stream());

xerr("3");
    tab.fmt("iteration, women years, total costs");

xerr("4");
    tab << hline();
    tab("iteration, women years, total costs");
    tab << hline();

    return tab;
}





